@@ -2,6 +2,34 @@
 # -*- coding: utf-8 -*-
 import clientinfo, hubinfo, protocol, socket, ssl, threading, nicklist
 
+class Clients:
+	
+	def __init__(self):
+		self.clientlist = []
+	
+	def addclient(self, cl):
+		if isinstance(cl, Client):
+			self.clientlist.append(cl)
+	
+	def getclientbyaddress(self, hubaddress):
+		for cl in self.clientlist:
+			if cl.clientinfo.hubaddress() == hubaddress:
+				return cl
+		return False
+
+	def makeclient(self, address, username, password, description, events={}, owner="", pid=""):
+		cl = Client()
+		cl.clientinfo.hubaddress(address)
+		cl.clientinfo.username = username
+		cl.clientinfo.password = password
+		cl.clientinfo.description = description
+		if len(events) > 0:
+			cl.events = events
+		cl.clientinfo.pid(pid)
+		cl.connect()
+		self.addclient(cl)
+		return cl
+
 class Client:
 	
 	def __init__(self):
@@ -13,7 +41,7 @@ class Client:
 		self.isconnected = None
 		self.debug = False
 		self.events = {}
-		
+	
 	def sckread(self):
 		while 1:
 			data = self.sckfile.readline()
